@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Test factories.
 """
@@ -11,12 +10,13 @@ import pytz
 from faker import Factory as FakerFactory
 from faker.providers import misc
 
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 
-from enterprise_data.models import EnterpriseEnrollment, EnterpriseUser
+from enterprise_data.models import EnterpriseEnrollment, EnterpriseLearner, EnterpriseLearnerEnrollment, EnterpriseUser
 
 FAKER = FakerFactory.create()
 FAKER.add_provider(misc)
+User = get_user_model()
 
 
 class EnterpriseEnrollmentFactory(factory.django.DjangoModelFactory):
@@ -80,10 +80,10 @@ class UserFactory(factory.django.DjangoModelFactory):
 
     _DEFAULT_PASSWORD = 'test'
 
-    username = factory.Sequence('robot{0}'.format)
-    email = factory.Sequence('robot+test+{0}@edx.org'.format)
+    username = factory.Sequence('robot{}'.format)
+    email = factory.Sequence('robot+test+{}@edx.org'.format)
     password = factory.PostGenerationMethodCall('set_password', _DEFAULT_PASSWORD)
-    first_name = factory.Sequence('Robot{0}'.format)
+    first_name = factory.Sequence('Robot{}'.format)
     last_name = 'Test'
     is_staff = factory.lazy_attribute(lambda x: False)
     is_active = True
@@ -106,12 +106,75 @@ class EnterpriseUserFactory(factory.django.DjangoModelFactory):
     enterprise_user_id = factory.lazy_attribute(lambda x: FAKER.random_int(min=1))  # pylint: disable=no-member
     enterprise_sso_uid = factory.lazy_attribute(lambda x: FAKER.text(max_nb_chars=255))  # pylint: disable=no-member
     user_account_creation_timestamp = datetime(2011, 1, 1, tzinfo=pytz.utc)
-    user_username = factory.Sequence('robot{0}'.format)
+    user_username = factory.Sequence('robot{}'.format)
     user_email = factory.lazy_attribute(lambda x: FAKER.email())  # pylint: disable=no-member
     user_country_code = factory.lazy_attribute(lambda x: FAKER.country_code())  # pylint: disable=no-member
     last_activity_date = datetime(2012, 1, 1).date()
 
 
+class EnterpriseLearnerFactory(factory.django.DjangoModelFactory):
+    """
+    EnterpriseLearner model Factory.
+    """
+    class Meta:
+        model = EnterpriseLearner
+
+    enterprise_user_id = factory.lazy_attribute(lambda x: FAKER.random_int(min=1))  # pylint: disable=no-member
+    enterprise_customer_uuid = str(FAKER.uuid4())  # pylint: disable=no-member
+    lms_user_created = datetime(2011, 1, 1, tzinfo=pytz.utc)
+    user_username = factory.Sequence('robot{}'.format)
+    user_email = factory.lazy_attribute(lambda x: FAKER.email())  # pylint: disable=no-member
+    lms_user_country = factory.lazy_attribute(lambda x: FAKER.country_code())  # pylint: disable=no-member
+    enterprise_sso_uid = factory.lazy_attribute(lambda x: FAKER.text(max_nb_chars=255))  # pylint: disable=no-member
+    last_activity_date = datetime(2012, 1, 1).date()
+
+
+class EnterpriseLearnerProgressFactory(factory.django.DjangoModelFactory):
+    """
+    EnterpriseLearnerEnrollment model factory.
+    """
+
+    class Meta:
+        model = EnterpriseLearnerEnrollment
+
+    id = factory.lazy_attribute(lambda x: FAKER.random_int(min=1, max=999999))  # pylint: disable=no-member,invalid-name
+    enterprise_customer_uuid = str(FAKER.uuid4())  # pylint: disable=no-member
+    course_run_key = factory.lazy_attribute(lambda x: FAKER.slug())  # pylint: disable=no-member
+    enrollment_date = factory.lazy_attribute(lambda x: '2018-01-01T00:00:00Z')
+    user_current_enrollment_mode = factory.lazy_attribute(lambda x: 'verified')
+    has_passed = factory.lazy_attribute(lambda x: FAKER.boolean())  # pylint: disable=no-member
+    is_consent_granted = True
+    course_title = factory.lazy_attribute(lambda x: ' '.join(FAKER.words(nb=2)).title())  # pylint: disable=no-member
+    course_start_date = factory.lazy_attribute(lambda x: FAKER.date_time_between(  # pylint: disable=no-member
+        start_date='-2M',
+        end_date='+2M',
+        tzinfo=pytz.utc)
+    )
+    user_email = factory.lazy_attribute(lambda x: FAKER.email())  # pylint: disable=no-member
+    current_grade = factory.lazy_attribute(
+        lambda x: FAKER.pyfloat(right_digits=2, min_value=0, max_value=1)  # pylint: disable=no-member
+    )
+
+    @factory.lazy_attribute
+    def course_end_date(self):
+        return FAKER.date_time_between(   # pylint: disable=no-member
+            start_date=self.course_start_date,
+            end_date="+8M",
+            tzinfo=pytz.utc
+        )
+
+    @factory.lazy_attribute
+    def passed_date(self):
+        """ Create a passed timestamp if a course has been passed """
+        if self.has_passed:
+            return FAKER.date_time_between(  # pylint: disable=no-member
+                start_date=self.course_start_date,
+                end_date=self.course_end_date,
+                tzinfo=pytz.utc
+            )
+        return None
+
+
 def get_dummy_enterprise_api_data(**kwargs):
     """
     DRY method to get enterprise dummy data.
